'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_blend_func_extended'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_blend_func_extended',error_checker=_errors._error_checker)
GL_MAX_DUAL_SOURCE_DRAW_BUFFERS=_C('GL_MAX_DUAL_SOURCE_DRAW_BUFFERS',0x88FC)
GL_ONE_MINUS_SRC1_ALPHA=_C('GL_ONE_MINUS_SRC1_ALPHA',0x88FB)
GL_ONE_MINUS_SRC1_COLOR=_C('GL_ONE_MINUS_SRC1_COLOR',0x88FA)
GL_SRC1_ALPHA=_C('GL_SRC1_ALPHA',0x8589)
GL_SRC1_COLOR=_C('GL_SRC1_COLOR',0x88F9)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,arrays.GLcharArray)
def glBindFragDataLocationIndexed(program,colorNumber,index,name):pass
@_f
@_p.types(_cs.GLint,_cs.GLuint,arrays.GLcharArray)
def glGetFragDataIndex(program,name):pass



"""Abstraction point for handling of data-pointers in OpenGL

The purpose of this package is to allow for the registration and dispatch
of handlers for different data-types in such a way that you can add new
data-types to the set of types which PyOpenGL will handle as arguments
to functions requiring typed pointers.

Possible data types:
    Numpy arrays
    Numarray arrays
    PyGame surfaces
    PyMedia buffers
    Python buffer-objects
    Memory-mapped files
    PIL images
"""
import ctypes
import OpenGL
from OpenGL.arrays.arraydatatype import *
from OpenGL.arrays import formathandler
from OpenGL.arrays.arrayhelpers import *



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_vertex_weighting'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_vertex_weighting',error_checker=_errors._error_checker)
GL_CURRENT_VERTEX_WEIGHT_EXT=_C('GL_CURRENT_VERTEX_WEIGHT_EXT',0x850B)
GL_MODELVIEW0_EXT=_C('GL_MODELVIEW0_EXT',0x1700)
GL_MODELVIEW0_MATRIX_EXT=_C('GL_MODELVIEW0_MATRIX_EXT',0x0BA6)
GL_MODELVIEW0_STACK_DEPTH_EXT=_C('GL_MODELVIEW0_STACK_DEPTH_EXT',0x0BA3)
GL_MODELVIEW1_EXT=_C('GL_MODELVIEW1_EXT',0x850A)
GL_MODELVIEW1_MATRIX_EXT=_C('GL_MODELVIEW1_MATRIX_EXT',0x8506)
GL_MODELVIEW1_STACK_DEPTH_EXT=_C('GL_MODELVIEW1_STACK_DEPTH_EXT',0x8502)
GL_VERTEX_WEIGHTING_EXT=_C('GL_VERTEX_WEIGHTING_EXT',0x8509)
GL_VERTEX_WEIGHT_ARRAY_EXT=_C('GL_VERTEX_WEIGHT_ARRAY_EXT',0x850C)
GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT=_C('GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT',0x8510)
GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT=_C('GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT',0x850D)
GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT=_C('GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT',0x850F)
GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT=_C('GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT',0x850E)
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glVertexWeightPointerEXT(size,type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLfloat)
def glVertexWeightfEXT(weight):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glVertexWeightfvEXT(weight):pass



'''OpenGL extension SGIX.swap_barrier

This module customises the behaviour of the 
OpenGL.raw.GLX.SGIX.swap_barrier to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides the capability to sychronize the buffer
	swaps of different swap groups.
	
	A swap group is bound to a _swap_barrier_.  The buffer swaps of each 
	swap group using that barrier will wait until every swap group using 
	that barrier is ready to swap (where readiness is defined below), after
	which time all buffer swaps of all groups using that barrier will
	take place concurrently.
	
	This extension extends the set of conditions that must be met before
	a buffer swap can take place. 

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/swap_barrier.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.SGIX.swap_barrier import *
from OpenGL.raw.GLX.SGIX.swap_barrier import _EXTENSION_NAME

def glInitSwapBarrierSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension KHR.fence_sync

This module customises the behaviour of the 
OpenGL.raw.EGL.KHR.fence_sync to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/KHR/fence_sync.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.EGL import _types, _glgets
from OpenGL.raw.EGL.KHR.fence_sync import *
from OpenGL.raw.EGL.KHR.fence_sync import _EXTENSION_NAME

def glInitFenceSyncKHR():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.draw_texture

This module customises the behaviour of the 
OpenGL.raw.GL.NV.draw_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a new function, DrawTextureNV(), allowing
	applications to draw an screen-aligned rectangle displaying some or all of
	the contents of a two-dimensional or rectangle texture.  Callers specify a
	texture object, an optional sampler object, window coordinates of the
	rectangle to draw, and texture coordinates corresponding to the corners of
	the rectangle.  For each fragment produced by the rectangle, DrawTextureNV
	interpolates the texture coordinates, performs a texture lookup, and uses
	the texture result as the fragment color.
	
	No shaders are used by DrawTextureNV; the results of the texture lookup
	are used in lieu of a fragment shader output.  The fragments generated are
	processed by all per-fragment operations.  In particular,
	DrawTextureNV() fully supports blending and multisampling.
	
	While this functionality can be obtained in unextended OpenGL by drawing a
	rectangle and using a fragment shader to do a texture lookup,
	DrawTextureNV() is likely to have better power efficiency on
	implementations supporting this extension.  Additionally, use of this
	extension frees the application developer from having to set up
	specialized shaders, transformation matrices, vertex attributes, and
	various other state in order to render the rectangle.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/draw_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.draw_texture import *
from OpenGL.raw.GL.NV.draw_texture import _EXTENSION_NAME

def glInitDrawTextureNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.dmbuffer

This module customises the behaviour of the 
OpenGL.raw.GLX.SGIX.dmbuffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces a new type of GLXPbuffer, a DM or Digital
	Media pbuffer.  A DM pbuffer is a GLXPbuffer that adopts one or more 
	of its buffers from an externally defined and allocated DMbuffer. 
	In this way it resembles a GLXPixmap that attaches to an existing
	X pixmap.  Like a standard pbuffer it can be used as a non-displayable
	rendering area, or as a read source for pixel data.  The externally
	defined buffers of the DM pbuffer can be sequentially associated 
	with other DM buffers of the same size and configuration.  
	
	.  The DM pbuffer is described with a new attrib passed to 
	   glXCreateGLXPbuffer.  
	
	.  A new GLX command allows associating a compatible DMbuffer with 
	   the DM GLXPbuffer.  At associate time the DM buffers described 
	   by the DMparams are used directly as the corresponding 
	   buffers of the GLXPbuffer drawable, as described by the FBconfig.  
	   All other buffers that are part of the config will be created by
	   GL without externally referenceable names.  A DM pbuffer must be
	   associated with a compatible DMbuffer before it can be made current
	   to a GLX context. 
	
	.  The externally defined buffers of the DM pbuffer can be changed at 
	   any time by successfully associating a new DMbuffer with the GLXPbuffer 
	   through the associate command.  It will be the application's 
	   responsibility to synchronize DMedia, GLX, and GL commands that 
	   effect the contents of the DM pbuffer.
	
	.  Any direct GLX rendering context that satisfies config compatibility
	   can be used to render to or read from a DM GLXPbuffer.
	   A currently associated DMbuffer may simultaneously be in use by 
	   other clients on the same Display, but will not be destroyed
	   while associated with a GLXPbuffer.  When the GLXpbuffer is
	   destroyed, all buffers that have no remaining clients, including
	   the DMbuffer, will be freed.
	
	DM GLXPbuffers are proposed as a means for OpenGL to access buffers
	generated by the VL, compression, and other digital media libraries in 
	a uniform way.  The DMbuffer and DMparams descriptors are left 
	intentionally abstract so that the GLX extension can adapt to future 
	DM library changes.  
	The initial implementation will require that the DMparams descriptor
	supply at least pixel format and packing information, and that the  
	DMbuffer provide the size and location of a colorbuffer.  GLX will do 
	compatibility checking when possible based on the config, params, and 
	buffer information at associate time. 

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/dmbuffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.SGIX.dmbuffer import *
from OpenGL.raw.GLX.SGIX.dmbuffer import _EXTENSION_NAME

def glInitDmbufferSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_VERSION_EGL_1_0'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_VERSION_EGL_1_0',error_checker=_errors._error_checker)
EGL_ALPHA_SIZE=_C('EGL_ALPHA_SIZE',0x3021)
EGL_BAD_ACCESS=_C('EGL_BAD_ACCESS',0x3002)
EGL_BAD_ALLOC=_C('EGL_BAD_ALLOC',0x3003)
EGL_BAD_ATTRIBUTE=_C('EGL_BAD_ATTRIBUTE',0x3004)
EGL_BAD_CONFIG=_C('EGL_BAD_CONFIG',0x3005)
EGL_BAD_CONTEXT=_C('EGL_BAD_CONTEXT',0x3006)
EGL_BAD_CURRENT_SURFACE=_C('EGL_BAD_CURRENT_SURFACE',0x3007)
EGL_BAD_DISPLAY=_C('EGL_BAD_DISPLAY',0x3008)
EGL_BAD_MATCH=_C('EGL_BAD_MATCH',0x3009)
EGL_BAD_NATIVE_PIXMAP=_C('EGL_BAD_NATIVE_PIXMAP',0x300A)
EGL_BAD_NATIVE_WINDOW=_C('EGL_BAD_NATIVE_WINDOW',0x300B)
EGL_BAD_PARAMETER=_C('EGL_BAD_PARAMETER',0x300C)
EGL_BAD_SURFACE=_C('EGL_BAD_SURFACE',0x300D)
EGL_BLUE_SIZE=_C('EGL_BLUE_SIZE',0x3022)
EGL_BUFFER_SIZE=_C('EGL_BUFFER_SIZE',0x3020)
EGL_CONFIG_CAVEAT=_C('EGL_CONFIG_CAVEAT',0x3027)
EGL_CONFIG_ID=_C('EGL_CONFIG_ID',0x3028)
EGL_CORE_NATIVE_ENGINE=_C('EGL_CORE_NATIVE_ENGINE',0x305B)
EGL_DEPTH_SIZE=_C('EGL_DEPTH_SIZE',0x3025)
# EGL_DONT_CARE=_C('EGL_DONT_CARE',((EGLint)-1))
EGL_DRAW=_C('EGL_DRAW',0x3059)
EGL_EXTENSIONS=_C('EGL_EXTENSIONS',0x3055)
EGL_FALSE=_C('EGL_FALSE',0)
EGL_GREEN_SIZE=_C('EGL_GREEN_SIZE',0x3023)
EGL_HEIGHT=_C('EGL_HEIGHT',0x3056)
EGL_LARGEST_PBUFFER=_C('EGL_LARGEST_PBUFFER',0x3058)
EGL_LEVEL=_C('EGL_LEVEL',0x3029)
EGL_MAX_PBUFFER_HEIGHT=_C('EGL_MAX_PBUFFER_HEIGHT',0x302A)
EGL_MAX_PBUFFER_PIXELS=_C('EGL_MAX_PBUFFER_PIXELS',0x302B)
EGL_MAX_PBUFFER_WIDTH=_C('EGL_MAX_PBUFFER_WIDTH',0x302C)
EGL_NATIVE_RENDERABLE=_C('EGL_NATIVE_RENDERABLE',0x302D)
EGL_NATIVE_VISUAL_ID=_C('EGL_NATIVE_VISUAL_ID',0x302E)
EGL_NATIVE_VISUAL_TYPE=_C('EGL_NATIVE_VISUAL_TYPE',0x302F)
EGL_NONE=_C('EGL_NONE',0x3038)
EGL_NON_CONFORMANT_CONFIG=_C('EGL_NON_CONFORMANT_CONFIG',0x3051)
EGL_NOT_INITIALIZED=_C('EGL_NOT_INITIALIZED',0x3001)
# EGL_NO_CONTEXT=_C('EGL_NO_CONTEXT',((EGLContext)0))
# EGL_NO_DISPLAY=_C('EGL_NO_DISPLAY',((EGLDisplay)0))
# EGL_NO_SURFACE=_C('EGL_NO_SURFACE',((EGLSurface)0))
EGL_PBUFFER_BIT=_C('EGL_PBUFFER_BIT',0x0001)
EGL_PIXMAP_BIT=_C('EGL_PIXMAP_BIT',0x0002)
EGL_READ=_C('EGL_READ',0x305A)
EGL_RED_SIZE=_C('EGL_RED_SIZE',0x3024)
EGL_SAMPLES=_C('EGL_SAMPLES',0x3031)
EGL_SAMPLE_BUFFERS=_C('EGL_SAMPLE_BUFFERS',0x3032)
EGL_SLOW_CONFIG=_C('EGL_SLOW_CONFIG',0x3050)
EGL_STENCIL_SIZE=_C('EGL_STENCIL_SIZE',0x3026)
EGL_SUCCESS=_C('EGL_SUCCESS',0x3000)
EGL_SURFACE_TYPE=_C('EGL_SURFACE_TYPE',0x3033)
EGL_TRANSPARENT_BLUE_VALUE=_C('EGL_TRANSPARENT_BLUE_VALUE',0x3035)
EGL_TRANSPARENT_GREEN_VALUE=_C('EGL_TRANSPARENT_GREEN_VALUE',0x3036)
EGL_TRANSPARENT_RED_VALUE=_C('EGL_TRANSPARENT_RED_VALUE',0x3037)
EGL_TRANSPARENT_RGB=_C('EGL_TRANSPARENT_RGB',0x3052)
EGL_TRANSPARENT_TYPE=_C('EGL_TRANSPARENT_TYPE',0x3034)
EGL_TRUE=_C('EGL_TRUE',1)
EGL_VENDOR=_C('EGL_VENDOR',0x3053)
EGL_VERSION=_C('EGL_VERSION',0x3054)
EGL_WIDTH=_C('EGL_WIDTH',0x3057)
EGL_WINDOW_BIT=_C('EGL_WINDOW_BIT',0x0004)
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,arrays.GLintArray,arrays.GLvoidpArray,_cs.EGLint,arrays.GLintArray)
def eglChooseConfig(dpy,attrib_list,configs,config_size,num_config):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface,_cs.EGLNativePixmapType)
def eglCopyBuffers(dpy,surface,target):pass
@_f
@_p.types(_cs.EGLContext,_cs.EGLDisplay,_cs.EGLConfig,_cs.EGLContext,arrays.GLintArray)
def eglCreateContext(dpy,config,share_context,attrib_list):pass
@_f
@_p.types(_cs.EGLSurface,_cs.EGLDisplay,_cs.EGLConfig,arrays.GLintArray)
def eglCreatePbufferSurface(dpy,config,attrib_list):pass
@_f
@_p.types(_cs.EGLSurface,_cs.EGLDisplay,_cs.EGLConfig,_cs.EGLNativePixmapType,arrays.GLintArray)
def eglCreatePixmapSurface(dpy,config,pixmap,attrib_list):pass
@_f
@_p.types(_cs.EGLSurface,_cs.EGLDisplay,_cs.EGLConfig,_cs.EGLNativeWindowType,arrays.GLintArray)
def eglCreateWindowSurface(dpy,config,win,attrib_list):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLContext)
def eglDestroyContext(dpy,ctx):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface)
def eglDestroySurface(dpy,surface):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLConfig,_cs.EGLint,arrays.GLintArray)
def eglGetConfigAttrib(dpy,config,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,arrays.GLvoidpArray,_cs.EGLint,arrays.GLintArray)
def eglGetConfigs(dpy,configs,config_size,num_config):pass
@_f
@_p.types(_cs.EGLDisplay,)
def eglGetCurrentDisplay():pass
@_f
@_p.types(_cs.EGLSurface,_cs.EGLint)
def eglGetCurrentSurface(readdraw):pass
@_f
@_p.types(_cs.EGLDisplay,_cs.EGLNativeDisplayType)
def eglGetDisplay(display_id):pass
@_f
@_p.types(_cs.EGLint,)
def eglGetError():pass
@_f
@_p.types(ctypes.c_void_p,arrays.GLbyteArray)
def eglGetProcAddress(procname):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,arrays.GLintArray,arrays.GLintArray)
def eglInitialize(dpy,major,minor):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface,_cs.EGLSurface,_cs.EGLContext)
def eglMakeCurrent(dpy,draw,read,ctx):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLContext,_cs.EGLint,arrays.GLintArray)
def eglQueryContext(dpy,ctx,attribute,value):pass
@_f
@_p.types(ctypes.c_char_p,_cs.EGLDisplay,_cs.EGLint)
def eglQueryString(dpy,name):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface,_cs.EGLint,arrays.GLintArray)
def eglQuerySurface(dpy,surface,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface)
def eglSwapBuffers(dpy,surface):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay)
def eglTerminate(dpy):pass
@_f
@_p.types(_cs.EGLBoolean,)
def eglWaitGL():pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLint)
def eglWaitNative(engine):pass



'''OpenGL extension ARB.compressed_texture_pixel_storage

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.compressed_texture_pixel_storage to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension expands the functionality of the PixelStore modes
	to allow UNPACK_ROW_LENGTH, UNPACK_SKIP_ROWS, UNPACK_SKIP_PIXELS,
	UNPACK_IMAGE_HEIGHT and UNPACK_SKIP_IMAGES to affect the operation of
	CompressedTexImage*D and CompressedTexSubImage*D. Similarly, it 
	also allows PACK_ROW_LENGTH, PACK_SKIP_ROWS, PACK_SKIP_PIXELS, 
	PACK_IMAGE_HEIGHT and PACK_SKIP_IMAGES to affect the operation of 
	GetCompressedTexImage*D. This allows data to be transferred
	to or from a specified sub-rectangle of a larger compressed image.
	
	This extension is designed primarily to support compressed image
	formats with fixed-size blocks. To use this new mechanism, an 
	application should program new parameters UNPACK_COMPRESSED_BLOCK_
	{WIDTH,HEIGHT,DEPTH,SIZE} to indicate the number of texels in each
	dimension of the fixed-size block as well as the number of bytes
	consumed by each block. These parameters, in addition to the 
	existing PixelStore parameters, are used to identify a collection 
	of bytes in client memory or a buffer object's data store to use
	as compressed texture data. This operation is unlikely to have 
	the desired results if the client programs a block size inconsistent
	with the underlying compressed image format, or if the compressed
	image format has variable-sized blocks.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/compressed_texture_pixel_storage.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.compressed_texture_pixel_storage import *
from OpenGL.raw.GL.ARB.compressed_texture_pixel_storage import _EXTENSION_NAME

def glInitCompressedTexturePixelStorageARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.texture_integer

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture_integer to provide a more 
Python-friendly API

Overview (from the spec)
	
	Fixed-point textures in unextended OpenGL have integer components,
	but those values are taken to represent floating-point values in
	the range [0,1].  These integer components are considered
	"normalized" integers.  When such a texture is accessed by a
	shader or by fixed-function fragment processing, floating-point
	values are returned.
	
	This extension provides a set of new "unnormalized" integer texture
	formats.  Formats with both signed and unsigned integers are provided.  In
	these formats, the components are treated as true integers.  When such
	textures are accessed by a shader, actual integer values are returned.
	
	Pixel operations that read from or write to a texture or color
	buffer with unnormalized integer components follow a path similar
	to that used for color index pixel operations, except that more
	than one component may be provided at once.  Integer values flow
	through the pixel processing pipe, and no pixel transfer
	operations are performed.  Integer format enumerants used for such
	operations indicate unnormalized integer data.
	
	Textures or render buffers with unnormalized integer formats may also be
	attached to framebuffer objects to receive fragment color values written
	by a fragment shader.  Per-fragment operations that require floating-point
	color components, including multisample alpha operations, alpha test,
	blending, and dithering, have no effect when the corresponding colors are
	written to an integer color buffer.  The NV_gpu_program4 and
	EXT_gpu_shader4 extensions add the capability to fragment programs and
	fragment shaders to write signed and unsigned integer output values.
	
	This extension does not enforce type consistency for texture accesses or
	between fragment shaders and the corresponding framebuffer attachments.
	The results of a texture lookup from an integer texture are undefined:
	
	  * for fixed-function fragment processing, or
	
	  * for shader texture accesses expecting floating-point return values.  
	
	The color components used for per-fragment operations and written into a
	color buffer are undefined:
	
	  * for fixed-function fragment processing with an integer color buffer,
	
	  * for fragment shaders that write floating-point color components to an
	    integer color buffer, or
	
	  * for fragment shaders that write integer color components to a color
	    buffer with floating point or normalized integer components.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_integer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.texture_integer import *
from OpenGL.raw.GL.EXT.texture_integer import _EXTENSION_NAME

def glInitTextureIntegerEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glTexParameterIivEXT.params size not checked against 'pname'
glTexParameterIivEXT=wrapper.wrapper(glTexParameterIivEXT).setInputArraySize(
    'params', None
)
# INPUT glTexParameterIuivEXT.params size not checked against 'pname'
glTexParameterIuivEXT=wrapper.wrapper(glTexParameterIuivEXT).setInputArraySize(
    'params', None
)
glGetTexParameterIivEXT=wrapper.wrapper(glGetTexParameterIivEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexParameterIuivEXT=wrapper.wrapper(glGetTexParameterIuivEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension QCOM.driver_control

This module customises the behaviour of the 
OpenGL.raw.GLES2.QCOM.driver_control to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/QCOM/driver_control.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.QCOM.driver_control import *
from OpenGL.raw.GLES2.QCOM.driver_control import _EXTENSION_NAME

def glInitDriverControlQCOM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glGetDriverControlsQCOM.driverControls size not checked against size
glGetDriverControlsQCOM=wrapper.wrapper(glGetDriverControlsQCOM).setInputArraySize(
    'driverControls', None
)
# INPUT glGetDriverControlStringQCOM.driverControlString size not checked against bufSize
glGetDriverControlStringQCOM=wrapper.wrapper(glGetDriverControlStringQCOM).setInputArraySize(
    'driverControlString', None
)
### END AUTOGENERATED SECTION


from OpenGL.arrays import vbo
from OpenGL.GL.VERSION import GL_1_5, GL_3_0, GL_3_1

class Implementation( vbo.Implementation ):
    """OpenGL-based implementation of VBO interfaces"""
    def __init__( self ):
        for name in self.EXPORTED_NAMES:
            found = False
            for source in (GL_1_5,GL_3_0, GL_3_1):
                try:
                    setattr( self, name, getattr( source, name ))
                except AttributeError as err:
                    pass 
                else:
                    found = True 
                    break 
            assert found, name
        if GL_1_5.glBufferData:
            self.available = True

Implementation.register()



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_vertex_program'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_vertex_program',error_checker=_errors._error_checker)
GL_COLOR_SUM_ARB=_C('GL_COLOR_SUM_ARB',0x8458)
GL_CURRENT_MATRIX_ARB=_C('GL_CURRENT_MATRIX_ARB',0x8641)
GL_CURRENT_MATRIX_STACK_DEPTH_ARB=_C('GL_CURRENT_MATRIX_STACK_DEPTH_ARB',0x8640)
GL_CURRENT_VERTEX_ATTRIB_ARB=_C('GL_CURRENT_VERTEX_ATTRIB_ARB',0x8626)
GL_MATRIX0_ARB=_C('GL_MATRIX0_ARB',0x88C0)
GL_MATRIX10_ARB=_C('GL_MATRIX10_ARB',0x88CA)
GL_MATRIX11_ARB=_C('GL_MATRIX11_ARB',0x88CB)
GL_MATRIX12_ARB=_C('GL_MATRIX12_ARB',0x88CC)
GL_MATRIX13_ARB=_C('GL_MATRIX13_ARB',0x88CD)
GL_MATRIX14_ARB=_C('GL_MATRIX14_ARB',0x88CE)
GL_MATRIX15_ARB=_C('GL_MATRIX15_ARB',0x88CF)
GL_MATRIX16_ARB=_C('GL_MATRIX16_ARB',0x88D0)
GL_MATRIX17_ARB=_C('GL_MATRIX17_ARB',0x88D1)
GL_MATRIX18_ARB=_C('GL_MATRIX18_ARB',0x88D2)
GL_MATRIX19_ARB=_C('GL_MATRIX19_ARB',0x88D3)
GL_MATRIX1_ARB=_C('GL_MATRIX1_ARB',0x88C1)
GL_MATRIX20_ARB=_C('GL_MATRIX20_ARB',0x88D4)
GL_MATRIX21_ARB=_C('GL_MATRIX21_ARB',0x88D5)
GL_MATRIX22_ARB=_C('GL_MATRIX22_ARB',0x88D6)
GL_MATRIX23_ARB=_C('GL_MATRIX23_ARB',0x88D7)
GL_MATRIX24_ARB=_C('GL_MATRIX24_ARB',0x88D8)
GL_MATRIX25_ARB=_C('GL_MATRIX25_ARB',0x88D9)
GL_MATRIX26_ARB=_C('GL_MATRIX26_ARB',0x88DA)
GL_MATRIX27_ARB=_C('GL_MATRIX27_ARB',0x88DB)
GL_MATRIX28_ARB=_C('GL_MATRIX28_ARB',0x88DC)
GL_MATRIX29_ARB=_C('GL_MATRIX29_ARB',0x88DD)
GL_MATRIX2_ARB=_C('GL_MATRIX2_ARB',0x88C2)
GL_MATRIX30_ARB=_C('GL_MATRIX30_ARB',0x88DE)
GL_MATRIX31_ARB=_C('GL_MATRIX31_ARB',0x88DF)
GL_MATRIX3_ARB=_C('GL_MATRIX3_ARB',0x88C3)
GL_MATRIX4_ARB=_C('GL_MATRIX4_ARB',0x88C4)
GL_MATRIX5_ARB=_C('GL_MATRIX5_ARB',0x88C5)
GL_MATRIX6_ARB=_C('GL_MATRIX6_ARB',0x88C6)
GL_MATRIX7_ARB=_C('GL_MATRIX7_ARB',0x88C7)
GL_MATRIX8_ARB=_C('GL_MATRIX8_ARB',0x88C8)
GL_MATRIX9_ARB=_C('GL_MATRIX9_ARB',0x88C9)
GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB=_C('GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB',0x88B1)
GL_MAX_PROGRAM_ATTRIBS_ARB=_C('GL_MAX_PROGRAM_ATTRIBS_ARB',0x88AD)
GL_MAX_PROGRAM_ENV_PARAMETERS_ARB=_C('GL_MAX_PROGRAM_ENV_PARAMETERS_ARB',0x88B5)
GL_MAX_PROGRAM_INSTRUCTIONS_ARB=_C('GL_MAX_PROGRAM_INSTRUCTIONS_ARB',0x88A1)
GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB=_C('GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB',0x88B4)
GL_MAX_PROGRAM_MATRICES_ARB=_C('GL_MAX_PROGRAM_MATRICES_ARB',0x862F)
GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB=_C('GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB',0x862E)
GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB=_C('GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB',0x88B3)
GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB=_C('GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB',0x88AF)
GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB=_C('GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB',0x88A3)
GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB=_C('GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB',0x88AB)
GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB=_C('GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB',0x88A7)
GL_MAX_PROGRAM_PARAMETERS_ARB=_C('GL_MAX_PROGRAM_PARAMETERS_ARB',0x88A9)
GL_MAX_PROGRAM_TEMPORARIES_ARB=_C('GL_MAX_PROGRAM_TEMPORARIES_ARB',0x88A5)
GL_MAX_VERTEX_ATTRIBS_ARB=_C('GL_MAX_VERTEX_ATTRIBS_ARB',0x8869)
GL_PROGRAM_ADDRESS_REGISTERS_ARB=_C('GL_PROGRAM_ADDRESS_REGISTERS_ARB',0x88B0)
GL_PROGRAM_ATTRIBS_ARB=_C('GL_PROGRAM_ATTRIBS_ARB',0x88AC)
GL_PROGRAM_BINDING_ARB=_C('GL_PROGRAM_BINDING_ARB',0x8677)
GL_PROGRAM_ERROR_POSITION_ARB=_C('GL_PROGRAM_ERROR_POSITION_ARB',0x864B)
GL_PROGRAM_ERROR_STRING_ARB=_C('GL_PROGRAM_ERROR_STRING_ARB',0x8874)
GL_PROGRAM_FORMAT_ARB=_C('GL_PROGRAM_FORMAT_ARB',0x8876)
GL_PROGRAM_FORMAT_ASCII_ARB=_C('GL_PROGRAM_FORMAT_ASCII_ARB',0x8875)
GL_PROGRAM_INSTRUCTIONS_ARB=_C('GL_PROGRAM_INSTRUCTIONS_ARB',0x88A0)
GL_PROGRAM_LENGTH_ARB=_C('GL_PROGRAM_LENGTH_ARB',0x8627)
GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB=_C('GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB',0x88B2)
GL_PROGRAM_NATIVE_ATTRIBS_ARB=_C('GL_PROGRAM_NATIVE_ATTRIBS_ARB',0x88AE)
GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB=_C('GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB',0x88A2)
GL_PROGRAM_NATIVE_PARAMETERS_ARB=_C('GL_PROGRAM_NATIVE_PARAMETERS_ARB',0x88AA)
GL_PROGRAM_NATIVE_TEMPORARIES_ARB=_C('GL_PROGRAM_NATIVE_TEMPORARIES_ARB',0x88A6)
GL_PROGRAM_PARAMETERS_ARB=_C('GL_PROGRAM_PARAMETERS_ARB',0x88A8)
GL_PROGRAM_STRING_ARB=_C('GL_PROGRAM_STRING_ARB',0x8628)
GL_PROGRAM_TEMPORARIES_ARB=_C('GL_PROGRAM_TEMPORARIES_ARB',0x88A4)
GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB=_C('GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB',0x88B6)
GL_TRANSPOSE_CURRENT_MATRIX_ARB=_C('GL_TRANSPOSE_CURRENT_MATRIX_ARB',0x88B7)
GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB',0x8622)
GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB',0x886A)
GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB',0x8645)
GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB',0x8623)
GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB',0x8624)
GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB',0x8625)
GL_VERTEX_PROGRAM_ARB=_C('GL_VERTEX_PROGRAM_ARB',0x8620)
GL_VERTEX_PROGRAM_POINT_SIZE_ARB=_C('GL_VERTEX_PROGRAM_POINT_SIZE_ARB',0x8642)
GL_VERTEX_PROGRAM_TWO_SIDE_ARB=_C('GL_VERTEX_PROGRAM_TWO_SIDE_ARB',0x8643)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindProgramARB(target,program):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteProgramsARB(n,programs):pass
@_f
@_p.types(None,_cs.GLuint)
def glDisableVertexAttribArrayARB(index):pass
@_f
@_p.types(None,_cs.GLuint)
def glEnableVertexAttribArrayARB(index):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenProgramsARB(n,programs):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLdoubleArray)
def glGetProgramEnvParameterdvARB(target,index,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLfloatArray)
def glGetProgramEnvParameterfvARB(target,index,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLdoubleArray)
def glGetProgramLocalParameterdvARB(target,index,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLfloatArray)
def glGetProgramLocalParameterfvARB(target,index,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glGetProgramStringARB(target,pname,string):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetProgramivARB(target,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLvoidpArray)
def glGetVertexAttribPointervARB(index,pname,pointer):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLdoubleArray)
def glGetVertexAttribdvARB(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetVertexAttribfvARB(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetVertexAttribivARB(index,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsProgramARB(program):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glProgramEnvParameter4dARB(target,index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLdoubleArray)
def glProgramEnvParameter4dvARB(target,index,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glProgramEnvParameter4fARB(target,index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLfloatArray)
def glProgramEnvParameter4fvARB(target,index,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glProgramLocalParameter4dARB(target,index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLdoubleArray)
def glProgramLocalParameter4dvARB(target,index,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glProgramLocalParameter4fARB(target,index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLfloatArray)
def glProgramLocalParameter4fvARB(target,index,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glProgramStringARB(target,format,len,string):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble)
def glVertexAttrib1dARB(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib1dvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat)
def glVertexAttrib1fARB(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib1fvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort)
def glVertexAttrib1sARB(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib1svARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble,_cs.GLdouble)
def glVertexAttrib2dARB(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib2dvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat)
def glVertexAttrib2fARB(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib2fvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort,_cs.GLshort)
def glVertexAttrib2sARB(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib2svARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glVertexAttrib3dARB(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib3dvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glVertexAttrib3fARB(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib3fvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glVertexAttrib3sARB(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib3svARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLbyteArray)
def glVertexAttrib4NbvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttrib4NivARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib4NsvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte)
def glVertexAttrib4NubARB(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLubyteArray)
def glVertexAttrib4NubvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttrib4NuivARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVertexAttrib4NusvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLbyteArray)
def glVertexAttrib4bvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glVertexAttrib4dARB(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib4dvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glVertexAttrib4fARB(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib4fvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttrib4ivARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glVertexAttrib4sARB(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib4svARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLubyteArray)
def glVertexAttrib4ubvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttrib4uivARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVertexAttrib4usvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLenum,_cs.GLboolean,_cs.GLsizei,ctypes.c_void_p)
def glVertexAttribPointerARB(index,size,type,normalized,stride,pointer):pass



'''OpenGL extension APPLE.vertex_array_object

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.vertex_array_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces named vertex array objects which encapsulate
	vertex array state on the client side. The main purpose of these 
	objects is to keep pointers to static vertex data and provide a name 
	for different sets of static vertex data.  
	
	By extending vertex array range functionality this extension allows multiple
	vertex array ranges to exist at one time, including their complete sets of
	state, in manner analogous to texture objects. 
	
	GenVertexArraysAPPLE creates a list of n number of vertex array object
	names.  After creating a name, BindVertexArrayAPPLE associates the name with
	a vertex array object and selects this vertex array and its associated
	state as current.  To get back to the default vertex array and its
	associated state the client should bind to vertex array named 0.
	
	Once a client is done using a vertex array object it can be deleted with
	DeleteVertexArraysAPPLE.  The client is responsible for allocating and
	deallocating the memory used by the vertex array data, while the
	DeleteVertexArraysAPPLE command deletes vertex array object names and
	associated state only.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/vertex_array_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.vertex_array_object import *
from OpenGL.raw.GL.APPLE.vertex_array_object import _EXTENSION_NAME

def glInitVertexArrayObjectAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDeleteVertexArraysAPPLE.arrays size not checked against n
glDeleteVertexArraysAPPLE=wrapper.wrapper(glDeleteVertexArraysAPPLE).setInputArraySize(
    'arrays', None
)
glGenVertexArraysAPPLE=wrapper.wrapper(glGenVertexArraysAPPLE).setOutput(
    'arrays',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension APPLE.texture_range

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.texture_range to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a method to specify the range of client address
	space that may be used by a texture.  In general, the storage size of a
	texture may be easily determined by the texture's data type and geometry.
	However, driver optimizations may be realized if an extended address
	range is specified to encompass the storage of multiple textures, or to
	encompass potential future changes in the size of a texture.  A typical
	usage of this extension is to specify an identical address range for
	several textures in a particular working set that encompasses the storage
	of all the textures in the set.  This allows the driver to make a single
	memory mapping for all of the textures.
	
	Further, a mechanism is provided to allow the application to give the GL
	driver a hint regarding the storage requirements of the texture data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/texture_range.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.texture_range import *
from OpenGL.raw.GL.APPLE.texture_range import _EXTENSION_NAME

def glInitTextureRangeAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glTextureRangeAPPLE.pointer size not checked against length
glTextureRangeAPPLE=wrapper.wrapper(glTextureRangeAPPLE).setInputArraySize(
    'pointer', None
)
glGetTexParameterPointervAPPLE=wrapper.wrapper(glGetTexParameterPointervAPPLE).setOutput(
    'params',size=(1,),orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.pipeline_statistics_query

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.pipeline_statistics_query to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces new query types that allow applications to get
	statistics information about different parts of the pipeline:
	
	  * Number of vertices and primitives issued to the GL;
	
	  * Number of times a vertex shader, tessellation evaluation shader,
	    geometry shader, fragment shader, and compute shader was invoked;
	
	  * Number of patches processed by the tessellation control shader stage;
	
	  * Number of primitives emitted by a geometry shader;
	
	  * Number of primitives that entered the primitive clipping stage;
	
	  * Number of primitives that are output by the primitive clipping stage;

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/pipeline_statistics_query.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.pipeline_statistics_query import *
from OpenGL.raw.GL.ARB.pipeline_statistics_query import _EXTENSION_NAME

def glInitPipelineStatisticsQueryARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.texture_env_combine4

This module customises the behaviour of the 
OpenGL.raw.GL.NV.texture_env_combine4 to provide a more 
Python-friendly API

Overview (from the spec)
	
	New texture environment function COMBINE4_NV allows programmable
	texture combiner operations, including
	
	    ADD                     Arg0 * Arg1 + Arg2 * Arg3
	    ADD_SIGNED_EXT          Arg0 * Arg1 + Arg2 * Arg3 - 0.5
	
	where Arg0, Arg1, Arg2 and Arg3 are derived from
	
	    ZERO                    the value 0
	    PRIMARY_COLOR_EXT       primary color of incoming fragment
	    TEXTURE                 texture color of corresponding texture unit
	    CONSTANT_EXT            texture environment constant color
	    PREVIOUS_EXT            result of previous texture environment; on
	                            texture unit 0, this maps to PRIMARY_COLOR_EXT
	    TEXTURE<n>_ARB          texture color of the <n>th texture unit
	
	In addition, the result may be scaled by 1.0, 2.0 or 4.0.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/texture_env_combine4.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.texture_env_combine4 import *
from OpenGL.raw.GL.NV.texture_env_combine4 import _EXTENSION_NAME

def glInitTextureEnvCombine4NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_DL_stereo_control'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_DL_stereo_control',error_checker=_errors._error_checker)
WGL_STEREO_EMITTER_DISABLE_3DL=_C('WGL_STEREO_EMITTER_DISABLE_3DL',0x2056)
WGL_STEREO_EMITTER_ENABLE_3DL=_C('WGL_STEREO_EMITTER_ENABLE_3DL',0x2055)
WGL_STEREO_POLARITY_INVERT_3DL=_C('WGL_STEREO_POLARITY_INVERT_3DL',0x2058)
WGL_STEREO_POLARITY_NORMAL_3DL=_C('WGL_STEREO_POLARITY_NORMAL_3DL',0x2057)
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.UINT)
def wglSetStereoEmitterState3DL(hDC,uState):pass



'''OpenGL extension ARB.color_buffer_float

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.color_buffer_float to provide a more 
Python-friendly API

Overview (from the spec)
	
	The standard OpenGL pipeline is based on a fixed-point pipeline.
	While color components are nominally floating-point values in the
	pipeline, components are frequently clamped to the range [0,1] to
	accomodate the fixed-point color buffer representation and allow
	for fixed-point computational hardware.
	
	This extension adds pixel formats or visuals with floating-point
	RGBA color components and controls for clamping of color
	components within the pipeline.
	
	For a floating-point RGBA pixel format, the size of each float
	components is specified using the same attributes that are used
	for defining the size of fixed-point components.  32-bit
	floating-point components are in the standard IEEE float format.
	16-bit floating-point components have 1 sign bit, 5 exponent bits,
	and 10 mantissa bits.
	
	Clamping control provides a way to disable certain color clamps
	and allow programs, and the fixed-function pipeline, to deal in
	unclamped colors.  There are controls to modify clamping of vertex
	colors, clamping of fragment colors throughout the pipeline, and
	for pixel return data.
	
	The default state for fragment clamping is "FIXED_ONLY", which
	has the behavior of clamping colors for fixed-point color buffers
	and not clamping colors for floating-pont color buffers.
	
	Vertex colors are clamped by default.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/color_buffer_float.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.color_buffer_float import *
from OpenGL.raw.GL.ARB.color_buffer_float import _EXTENSION_NAME

def glInitColorBufferFloatARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_transform_feedback'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_transform_feedback',error_checker=_errors._error_checker)
GL_INTERLEAVED_ATTRIBS_EXT=_C('GL_INTERLEAVED_ATTRIBS_EXT',0x8C8C)
GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_EXT=_C('GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_EXT',0x8C8A)
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_EXT=_C('GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_EXT',0x8C8B)
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_EXT=_C('GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_EXT',0x8C80)
GL_PRIMITIVES_GENERATED_EXT=_C('GL_PRIMITIVES_GENERATED_EXT',0x8C87)
GL_RASTERIZER_DISCARD_EXT=_C('GL_RASTERIZER_DISCARD_EXT',0x8C89)
GL_SEPARATE_ATTRIBS_EXT=_C('GL_SEPARATE_ATTRIBS_EXT',0x8C8D)
GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_EXT=_C('GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_EXT',0x8C8F)
GL_TRANSFORM_FEEDBACK_BUFFER_EXT=_C('GL_TRANSFORM_FEEDBACK_BUFFER_EXT',0x8C8E)
GL_TRANSFORM_FEEDBACK_BUFFER_MODE_EXT=_C('GL_TRANSFORM_FEEDBACK_BUFFER_MODE_EXT',0x8C7F)
GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_EXT=_C('GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_EXT',0x8C85)
GL_TRANSFORM_FEEDBACK_BUFFER_START_EXT=_C('GL_TRANSFORM_FEEDBACK_BUFFER_START_EXT',0x8C84)
GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_EXT=_C('GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_EXT',0x8C88)
GL_TRANSFORM_FEEDBACK_VARYINGS_EXT=_C('GL_TRANSFORM_FEEDBACK_VARYINGS_EXT',0x8C83)
GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH_EXT=_C('GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH_EXT',0x8C76)
@_f
@_p.types(None,_cs.GLenum)
def glBeginTransformFeedbackEXT(primitiveMode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint)
def glBindBufferBaseEXT(target,index,buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLintptr)
def glBindBufferOffsetEXT(target,index,buffer,offset):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr)
def glBindBufferRangeEXT(target,index,buffer,offset,size):pass
@_f
@_p.types(None,)
def glEndTransformFeedbackEXT():pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLsizeiArray,arrays.GLuintArray,arrays.GLcharArray)
def glGetTransformFeedbackVaryingEXT(program,index,bufSize,length,size,type,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,ctypes.POINTER( ctypes.POINTER( _cs.GLchar )),_cs.GLenum)
def glTransformFeedbackVaryingsEXT(program,count,varyings,bufferMode):pass



'''OpenGL extension ANDROID.extension_pack_es31a

This module customises the behaviour of the 
OpenGL.raw.GLES2.ANDROID.extension_pack_es31a to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ANDROID/extension_pack_es31a.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.ANDROID.extension_pack_es31a import *
from OpenGL.raw.GLES2.ANDROID.extension_pack_es31a import _EXTENSION_NAME

def glInitExtensionPackEs31AANDROID():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIS_fog_function'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIS_fog_function',error_checker=_errors._error_checker)
GL_FOG_FUNC_POINTS_SGIS=_C('GL_FOG_FUNC_POINTS_SGIS',0x812B)
GL_FOG_FUNC_SGIS=_C('GL_FOG_FUNC_SGIS',0x812A)
GL_MAX_FOG_FUNC_POINTS_SGIS=_C('GL_MAX_FOG_FUNC_POINTS_SGIS',0x812C)
@_f
@_p.types(None,_cs.GLsizei,arrays.GLfloatArray)
def glFogFuncSGIS(n,points):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glGetFogFuncSGIS(points):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_shadow_samplers'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_shadow_samplers',error_checker=_errors._error_checker)
GL_COMPARE_REF_TO_TEXTURE_EXT=_C('GL_COMPARE_REF_TO_TEXTURE_EXT',0x884E)
GL_SAMPLER_2D_SHADOW_EXT=_C('GL_SAMPLER_2D_SHADOW_EXT',0x8B62)
GL_TEXTURE_COMPARE_FUNC_EXT=_C('GL_TEXTURE_COMPARE_FUNC_EXT',0x884D)
GL_TEXTURE_COMPARE_MODE_EXT=_C('GL_TEXTURE_COMPARE_MODE_EXT',0x884C)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_evaluators'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_evaluators',error_checker=_errors._error_checker)
GL_EVAL_2D_NV=_C('GL_EVAL_2D_NV',0x86C0)
GL_EVAL_FRACTIONAL_TESSELLATION_NV=_C('GL_EVAL_FRACTIONAL_TESSELLATION_NV',0x86C5)
GL_EVAL_TRIANGULAR_2D_NV=_C('GL_EVAL_TRIANGULAR_2D_NV',0x86C1)
GL_EVAL_VERTEX_ATTRIB0_NV=_C('GL_EVAL_VERTEX_ATTRIB0_NV',0x86C6)
GL_EVAL_VERTEX_ATTRIB10_NV=_C('GL_EVAL_VERTEX_ATTRIB10_NV',0x86D0)
GL_EVAL_VERTEX_ATTRIB11_NV=_C('GL_EVAL_VERTEX_ATTRIB11_NV',0x86D1)
GL_EVAL_VERTEX_ATTRIB12_NV=_C('GL_EVAL_VERTEX_ATTRIB12_NV',0x86D2)
GL_EVAL_VERTEX_ATTRIB13_NV=_C('GL_EVAL_VERTEX_ATTRIB13_NV',0x86D3)
GL_EVAL_VERTEX_ATTRIB14_NV=_C('GL_EVAL_VERTEX_ATTRIB14_NV',0x86D4)
GL_EVAL_VERTEX_ATTRIB15_NV=_C('GL_EVAL_VERTEX_ATTRIB15_NV',0x86D5)
GL_EVAL_VERTEX_ATTRIB1_NV=_C('GL_EVAL_VERTEX_ATTRIB1_NV',0x86C7)
GL_EVAL_VERTEX_ATTRIB2_NV=_C('GL_EVAL_VERTEX_ATTRIB2_NV',0x86C8)
GL_EVAL_VERTEX_ATTRIB3_NV=_C('GL_EVAL_VERTEX_ATTRIB3_NV',0x86C9)
GL_EVAL_VERTEX_ATTRIB4_NV=_C('GL_EVAL_VERTEX_ATTRIB4_NV',0x86CA)
GL_EVAL_VERTEX_ATTRIB5_NV=_C('GL_EVAL_VERTEX_ATTRIB5_NV',0x86CB)
GL_EVAL_VERTEX_ATTRIB6_NV=_C('GL_EVAL_VERTEX_ATTRIB6_NV',0x86CC)
GL_EVAL_VERTEX_ATTRIB7_NV=_C('GL_EVAL_VERTEX_ATTRIB7_NV',0x86CD)
GL_EVAL_VERTEX_ATTRIB8_NV=_C('GL_EVAL_VERTEX_ATTRIB8_NV',0x86CE)
GL_EVAL_VERTEX_ATTRIB9_NV=_C('GL_EVAL_VERTEX_ATTRIB9_NV',0x86CF)
GL_MAP_ATTRIB_U_ORDER_NV=_C('GL_MAP_ATTRIB_U_ORDER_NV',0x86C3)
GL_MAP_ATTRIB_V_ORDER_NV=_C('GL_MAP_ATTRIB_V_ORDER_NV',0x86C4)
GL_MAP_TESSELLATION_NV=_C('GL_MAP_TESSELLATION_NV',0x86C2)
GL_MAX_MAP_TESSELLATION_NV=_C('GL_MAX_MAP_TESSELLATION_NV',0x86D6)
GL_MAX_RATIONAL_EVAL_ORDER_NV=_C('GL_MAX_RATIONAL_EVAL_ORDER_NV',0x86D7)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glEvalMapsNV(target,mode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetMapAttribParameterfvNV(target,index,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetMapAttribParameterivNV(target,index,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLboolean,ctypes.c_void_p)
def glGetMapControlPointsNV(target,index,type,ustride,vstride,packed,points):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetMapParameterfvNV(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetMapParameterivNV(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLint,_cs.GLboolean,ctypes.c_void_p)
def glMapControlPointsNV(target,index,type,ustride,vstride,uorder,vorder,packed,points):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glMapParameterfvNV(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glMapParameterivNV(target,pname,params):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_OES_draw_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_OES_draw_texture',error_checker=_errors._error_checker)
GL_TEXTURE_CROP_RECT_OES=_C('GL_TEXTURE_CROP_RECT_OES',0x8B9D)
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glDrawTexfOES(x,y,z,width,height):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glDrawTexfvOES(coords):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glDrawTexiOES(x,y,z,width,height):pass
@_f
@_p.types(None,arrays.GLintArray)
def glDrawTexivOES(coords):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glDrawTexsOES(x,y,z,width,height):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glDrawTexsvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glDrawTexxOES(x,y,z,width,height):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glDrawTexxvOES(coords):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_separate_shader_objects'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_separate_shader_objects',error_checker=_errors._error_checker)
GL_ACTIVE_PROGRAM_EXT=_C('GL_ACTIVE_PROGRAM_EXT',0x8B8D)
GL_ACTIVE_PROGRAM_EXT=_C('GL_ACTIVE_PROGRAM_EXT',0x8B8D)
GL_ALL_SHADER_BITS_EXT=_C('GL_ALL_SHADER_BITS_EXT',0xFFFFFFFF)
GL_FRAGMENT_SHADER_BIT_EXT=_C('GL_FRAGMENT_SHADER_BIT_EXT',0x00000002)
GL_PROGRAM_PIPELINE_BINDING_EXT=_C('GL_PROGRAM_PIPELINE_BINDING_EXT',0x825A)
GL_PROGRAM_SEPARABLE_EXT=_C('GL_PROGRAM_SEPARABLE_EXT',0x8258)
GL_VERTEX_SHADER_BIT_EXT=_C('GL_VERTEX_SHADER_BIT_EXT',0x00000001)
@_f
@_p.types(None,_cs.GLuint)
def glActiveProgramEXT(program):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glActiveShaderProgramEXT(pipeline,program):pass
@_f
@_p.types(None,_cs.GLuint)
def glBindProgramPipelineEXT(pipeline):pass
@_f
@_p.types(_cs.GLuint,_cs.GLenum,arrays.GLcharArray)
def glCreateShaderProgramEXT(type,string):pass
@_f
@_p.types(_cs.GLuint,_cs.GLenum,_cs.GLsizei,ctypes.POINTER( ctypes.POINTER( _cs.GLchar )))
def glCreateShaderProgramvEXT(type,count,strings):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteProgramPipelinesEXT(n,pipelines):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenProgramPipelinesEXT(n,pipelines):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetProgramPipelineInfoLogEXT(pipeline,bufSize,length,infoLog):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetProgramPipelineivEXT(pipeline,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsProgramPipelineEXT(pipeline):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLint)
def glProgramParameteriEXT(program,pname,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLfloat)
def glProgramUniform1fEXT(program,location,v0):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glProgramUniform1fvEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint)
def glProgramUniform1iEXT(program,location,v0):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glProgramUniform1ivEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLuint)
def glProgramUniform1uiEXT(program,location,v0):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glProgramUniform1uivEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLfloat,_cs.GLfloat)
def glProgramUniform2fEXT(program,location,v0,v1):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glProgramUniform2fvEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint)
def glProgramUniform2iEXT(program,location,v0,v1):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glProgramUniform2ivEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLuint,_cs.GLuint)
def glProgramUniform2uiEXT(program,location,v0,v1):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glProgramUniform2uivEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glProgramUniform3fEXT(program,location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glProgramUniform3fvEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glProgramUniform3iEXT(program,location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glProgramUniform3ivEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glProgramUniform3uiEXT(program,location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glProgramUniform3uivEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glProgramUniform4fEXT(program,location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glProgramUniform4fvEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glProgramUniform4iEXT(program,location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glProgramUniform4ivEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glProgramUniform4uiEXT(program,location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glProgramUniform4uivEXT(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix2fvEXT(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix2x3fvEXT(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix2x4fvEXT(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix3fvEXT(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix3x2fvEXT(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix3x4fvEXT(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix4fvEXT(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix4fvEXT(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix4x2fvEXT(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix4x3fvEXT(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLbitfield,_cs.GLuint)
def glUseProgramStagesEXT(pipeline,stages,program):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glUseShaderProgramEXT(type,program):pass
@_f
@_p.types(None,_cs.GLuint)
def glValidateProgramPipelineEXT(pipeline):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_occlusion_query'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_occlusion_query',error_checker=_errors._error_checker)
GL_CURRENT_OCCLUSION_QUERY_ID_NV=_C('GL_CURRENT_OCCLUSION_QUERY_ID_NV',0x8865)
GL_PIXEL_COUNTER_BITS_NV=_C('GL_PIXEL_COUNTER_BITS_NV',0x8864)
GL_PIXEL_COUNT_AVAILABLE_NV=_C('GL_PIXEL_COUNT_AVAILABLE_NV',0x8867)
GL_PIXEL_COUNT_NV=_C('GL_PIXEL_COUNT_NV',0x8866)
@_f
@_p.types(None,_cs.GLuint)
def glBeginOcclusionQueryNV(id):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteOcclusionQueriesNV(n,ids):pass
@_f
@_p.types(None,)
def glEndOcclusionQueryNV():pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenOcclusionQueriesNV(n,ids):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetOcclusionQueryivNV(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetOcclusionQueryuivNV(id,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsOcclusionQueryNV(id):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_NV_video_output'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_NV_video_output',error_checker=_errors._error_checker)
WGL_BIND_TO_VIDEO_RGBA_NV=_C('WGL_BIND_TO_VIDEO_RGBA_NV',0x20C1)
WGL_BIND_TO_VIDEO_RGB_AND_DEPTH_NV=_C('WGL_BIND_TO_VIDEO_RGB_AND_DEPTH_NV',0x20C2)
WGL_BIND_TO_VIDEO_RGB_NV=_C('WGL_BIND_TO_VIDEO_RGB_NV',0x20C0)
WGL_VIDEO_OUT_ALPHA_NV=_C('WGL_VIDEO_OUT_ALPHA_NV',0x20C4)
WGL_VIDEO_OUT_COLOR_AND_ALPHA_NV=_C('WGL_VIDEO_OUT_COLOR_AND_ALPHA_NV',0x20C6)
WGL_VIDEO_OUT_COLOR_AND_DEPTH_NV=_C('WGL_VIDEO_OUT_COLOR_AND_DEPTH_NV',0x20C7)
WGL_VIDEO_OUT_COLOR_NV=_C('WGL_VIDEO_OUT_COLOR_NV',0x20C3)
WGL_VIDEO_OUT_DEPTH_NV=_C('WGL_VIDEO_OUT_DEPTH_NV',0x20C5)
WGL_VIDEO_OUT_FIELD_1=_C('WGL_VIDEO_OUT_FIELD_1',0x20C9)
WGL_VIDEO_OUT_FIELD_2=_C('WGL_VIDEO_OUT_FIELD_2',0x20CA)
WGL_VIDEO_OUT_FRAME=_C('WGL_VIDEO_OUT_FRAME',0x20C8)
WGL_VIDEO_OUT_STACKED_FIELDS_1_2=_C('WGL_VIDEO_OUT_STACKED_FIELDS_1_2',0x20CB)
WGL_VIDEO_OUT_STACKED_FIELDS_2_1=_C('WGL_VIDEO_OUT_STACKED_FIELDS_2_1',0x20CC)
@_f
@_p.types(_cs.BOOL,_cs.HPVIDEODEV,_cs.HPBUFFERARB,_cs.c_int)
def wglBindVideoImageNV(hVideoDevice,hPbuffer,iVideoBuffer):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,ctypes.POINTER(_cs.HPVIDEODEV))
def wglGetVideoDeviceNV(hDC,numDevices,hVideoDevice):pass
@_f
@_p.types(_cs.BOOL,_cs.HPVIDEODEV,ctypes.POINTER(_cs.c_ulong),ctypes.POINTER(_cs.c_ulong))
def wglGetVideoInfoNV(hpVideoDevice,pulCounterOutputPbuffer,pulCounterOutputVideo):pass
@_f
@_p.types(_cs.BOOL,_cs.HPVIDEODEV)
def wglReleaseVideoDeviceNV(hVideoDevice):pass
@_f
@_p.types(_cs.BOOL,_cs.HPBUFFERARB,_cs.c_int)
def wglReleaseVideoImageNV(hPbuffer,iVideoBuffer):pass
@_f
@_p.types(_cs.BOOL,_cs.HPBUFFERARB,_cs.c_int,ctypes.POINTER(_cs.c_ulong),_cs.BOOL)
def wglSendPbufferToVideoNV(hPbuffer,iBufferType,pulCounterPbuffer,bBlock):pass



from OpenGL.arrays import vbo
from OpenGL.GL.ARB import vertex_buffer_object
from OpenGL.GL.ARB import uniform_buffer_object
from OpenGL.GL.ARB import texture_buffer_object
from OpenGL.GL.ARB import enhanced_layouts

class Implementation( vbo.Implementation ):
    """OpenGL ARB extension-based implementation of VBO interfaces"""
    def __init__( self ):
        for name in self.EXPORTED_NAMES:
            source = name
            if name.startswith( 'GL_'):
                source = name + '_ARB'
            else:
                source = name + 'ARB'
            found = False
            for source_extension in (
                vertex_buffer_object,
                uniform_buffer_object,
                texture_buffer_object,
                enhanced_layouts,
            ):
                try:
                    setattr( self, name, getattr( source_extension, source ))
                except AttributeError as err:
                    try:
                        setattr( self, name, getattr( source_extension, name ))
                    except AttributeError as err:
                        pass 
                    else:
                        found = True
                else:
                    found =True 
                    break
            assert found, name
        if self.glGenBuffers:
            self.available = True
Implementation.register()



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_AMD_occlusion_query_event'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_AMD_occlusion_query_event',error_checker=_errors._error_checker)
GL_OCCLUSION_QUERY_EVENT_MASK_AMD=_C('GL_OCCLUSION_QUERY_EVENT_MASK_AMD',0x874F)
GL_QUERY_ALL_EVENT_BITS_AMD=_C('GL_QUERY_ALL_EVENT_BITS_AMD',0xFFFFFFFF)
GL_QUERY_DEPTH_BOUNDS_FAIL_EVENT_BIT_AMD=_C('GL_QUERY_DEPTH_BOUNDS_FAIL_EVENT_BIT_AMD',0x00000008)
GL_QUERY_DEPTH_FAIL_EVENT_BIT_AMD=_C('GL_QUERY_DEPTH_FAIL_EVENT_BIT_AMD',0x00000002)
GL_QUERY_DEPTH_PASS_EVENT_BIT_AMD=_C('GL_QUERY_DEPTH_PASS_EVENT_BIT_AMD',0x00000001)
GL_QUERY_STENCIL_FAIL_EVENT_BIT_AMD=_C('GL_QUERY_STENCIL_FAIL_EVENT_BIT_AMD',0x00000004)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,_cs.GLuint)
def glQueryObjectParameteruiAMD(target,id,pname,param):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_QCOM_driver_control'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_QCOM_driver_control',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLuint)
def glDisableDriverControlQCOM(driverControl):pass
@_f
@_p.types(None,_cs.GLuint)
def glEnableDriverControlQCOM(driverControl):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetDriverControlStringQCOM(driverControl,bufSize,length,driverControlString):pass
@_f
@_p.types(None,arrays.GLintArray,_cs.GLsizei,arrays.GLuintArray)
def glGetDriverControlsQCOM(num,size,driverControls):pass



"""String-array-handling code for PyOpenGL
"""
from OpenGL.raw.GL import _types 
from OpenGL.raw.GL.VERSION import GL_1_1
from OpenGL.arrays import formathandler
import ctypes
from OpenGL import _bytes, error
from OpenGL._configflags import ERROR_ON_COPY

def dataPointer( value, typeCode=None ):
    return ctypes.cast(ctypes.c_char_p(value),
                           ctypes.c_void_p).value

class StringHandler( formathandler.FormatHandler ):
    """String-specific data-type handler for OpenGL"""
    HANDLED_TYPES = (_bytes.bytes, )
    @classmethod
    def from_param( cls, value, typeCode=None ):
        return ctypes.c_void_p( dataPointer( value ) )
    dataPointer = staticmethod( dataPointer )
    def zeros( self, dims, typeCode=None ):
        """Currently don't allow strings as output types!"""
        raise NotImplemented( """Don't currently support strings as output arrays""" )
    def ones( self, dims, typeCode=None ):
        """Currently don't allow strings as output types!"""
        raise NotImplemented( """Don't currently support strings as output arrays""" )
    def arrayToGLType( self, value ):
        """Given a value, guess OpenGL type of the corresponding pointer"""
        raise NotImplemented( """Can't guess data-type from a string-type argument""" )
    def arraySize( self, value, typeCode = None ):
        """Given a data-value, calculate ravelled size for the array"""
        # need to get bits-per-element...
        byteCount = BYTE_SIZES[ typeCode ]
        return len(value)//byteCount
    def arrayByteCount( self, value, typeCode = None ):
        """Given a data-value, calculate number of bytes required to represent"""
        return len(value)
    def asArray( self, value, typeCode=None ):
        """Convert given value to an array value of given typeCode"""
        if isinstance( value, bytes ):
            return value
        elif hasattr( value, 'tostring' ):
            return value.tostring()
        elif hasattr( value, 'raw' ):
            return value.raw
        # could convert types to string here, but we're not registered for
        # anything save string types...
        raise TypeError( """String handler got non-string object: %r"""%(type(value)))
    def dimensions( self, value, typeCode=None ):
        """Determine dimensions of the passed array value (if possible)"""
        raise TypeError(
            """Cannot calculate dimensions for a String data-type"""
        )

class UnicodeHandler( StringHandler ):
    HANDLED_TYPES = (_bytes.unicode,)
    @classmethod
    def from_param( cls, value, typeCode=None ):
        # TODO: raise CopyError if the flag is set!
        converted = _bytes.as_8_bit( value )
        result = StringHandler.from_param( converted )
        if converted is not value:
            if ERROR_ON_COPY:
                raise error.CopyError(
                    """Unicode string passed, cannot copy with ERROR_ON_COPY set, please use 8-bit strings"""
                )
            result._temporary_array_ = converted 
        return result
    def asArray( self, value, typeCode=None ):
        value = _bytes.as_8_bit( value )
        return StringHandler.asArray( self, value, typeCode=typeCode )


BYTE_SIZES = {
    GL_1_1.GL_DOUBLE: ctypes.sizeof( _types.GLdouble ),
    GL_1_1.GL_FLOAT: ctypes.sizeof( _types.GLfloat ),
    GL_1_1.GL_INT: ctypes.sizeof( _types.GLint ),
    GL_1_1.GL_SHORT: ctypes.sizeof( _types.GLshort ),
    GL_1_1.GL_UNSIGNED_BYTE: ctypes.sizeof( _types.GLubyte ),
    GL_1_1.GL_UNSIGNED_SHORT: ctypes.sizeof( _types.GLshort ),
    GL_1_1.GL_BYTE: ctypes.sizeof( _types.GLbyte ),
    GL_1_1.GL_UNSIGNED_INT: ctypes.sizeof( _types.GLuint ),
}



'''OpenGL extension AMD.gcn_shader

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.gcn_shader to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension exposes miscellaneous features of the AMD "Graphics Core
	Next" shader architecture that do not cleanly fit into other extensions
	and are not significant enough alone to warrant their own extensions.
	This includes cross-SIMD lane ballots, cube map query functions and
	a functionality to query the elapsed shader core time.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/gcn_shader.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.gcn_shader import *
from OpenGL.raw.GL.AMD.gcn_shader import _EXTENSION_NAME

def glInitGcnShaderAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.texture_sRGB

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture_sRGB to provide a more 
Python-friendly API

Overview (from the spec)
	
	Conventional texture formats assume a linear color space.  So for
	a conventional internal texture format such as GL_RGB8, the 256
	discrete values for each 8-bit color component map linearly and
	uniformly to the [0,1] range.
	
	The sRGB color space is based on typical (non-linear) monitor
	characteristics expected in a dimly lit office.  It has been
	standardized by the International Electrotechnical Commission (IEC)
	as IEC 61966-2-1. The sRGB color space roughly corresponds to 2.2
	gamma correction.
	
	This extension adds a few new uncompressed and compressed color
	texture formats with sRGB color components.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_sRGB.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.texture_sRGB import *
from OpenGL.raw.GL.EXT.texture_sRGB import _EXTENSION_NAME

def glInitTextureSrgbEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension PGI.vertex_hints

This module customises the behaviour of the 
OpenGL.raw.GL.PGI.vertex_hints to provide a more 
Python-friendly API

Overview (from the spec)
	
	The extension allows the app to give hints regarding what kinds of
	OpenGL function calls will happen between Begin/End pairs.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/PGI/vertex_hints.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.PGI.vertex_hints import *
from OpenGL.raw.GL.PGI.vertex_hints import _EXTENSION_NAME

def glInitVertexHintsPGI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension VERSION.GL_2_1

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_2_1 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_2_1.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_2_1 import *
from OpenGL.raw.GL.VERSION.GL_2_1 import _EXTENSION_NAME

def glInitGl21VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glUniformMatrix2x3fv.value size not checked against count*6
glUniformMatrix2x3fv=wrapper.wrapper(glUniformMatrix2x3fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3x2fv.value size not checked against count*6
glUniformMatrix3x2fv=wrapper.wrapper(glUniformMatrix3x2fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix2x4fv.value size not checked against count*8
glUniformMatrix2x4fv=wrapper.wrapper(glUniformMatrix2x4fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4x2fv.value size not checked against count*8
glUniformMatrix4x2fv=wrapper.wrapper(glUniformMatrix4x2fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3x4fv.value size not checked against count*12
glUniformMatrix3x4fv=wrapper.wrapper(glUniformMatrix3x4fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4x3fv.value size not checked against count*12
glUniformMatrix4x3fv=wrapper.wrapper(glUniformMatrix4x3fv).setInputArraySize(
    'value', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_vertex_array_range'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_vertex_array_range',error_checker=_errors._error_checker)
GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV=_C('GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV',0x8520)
GL_VERTEX_ARRAY_RANGE_LENGTH_NV=_C('GL_VERTEX_ARRAY_RANGE_LENGTH_NV',0x851E)
GL_VERTEX_ARRAY_RANGE_NV=_C('GL_VERTEX_ARRAY_RANGE_NV',0x851D)
GL_VERTEX_ARRAY_RANGE_POINTER_NV=_C('GL_VERTEX_ARRAY_RANGE_POINTER_NV',0x8521)
GL_VERTEX_ARRAY_RANGE_VALID_NV=_C('GL_VERTEX_ARRAY_RANGE_VALID_NV',0x851F)
@_f
@_p.types(None,)
def glFlushVertexArrayRangeNV():pass
@_f
@_p.types(None,_cs.GLsizei,ctypes.c_void_p)
def glVertexArrayRangeNV(length,pointer):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_DFX_multisample'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_DFX_multisample',error_checker=_errors._error_checker)
GL_MULTISAMPLE_3DFX=_C('GL_MULTISAMPLE_3DFX',0x86B2)
GL_MULTISAMPLE_BIT_3DFX=_C('GL_MULTISAMPLE_BIT_3DFX',0x20000000)
GL_SAMPLES_3DFX=_C('GL_SAMPLES_3DFX',0x86B4)
GL_SAMPLE_BUFFERS_3DFX=_C('GL_SAMPLE_BUFFERS_3DFX',0x86B3)




"""GLX (x-windows)-specific platform features"""
import ctypes, ctypes.util
from functools import wraps
from OpenGL.platform import baseplatform, ctypesloader

class GLXPlatform( baseplatform.BasePlatform ):
    """Posix (Linux, FreeBSD, etceteras) implementation for PyOpenGL"""
    # On Linux (and, I assume, most GLX platforms, we have to load 
    # GL and GLU with the "global" flag to allow GLUT to resolve its
    # references to GL/GLU functions).
    @baseplatform.lazy_property
    def GL(self):
        try:
            return ctypesloader.loadLibrary(
                ctypes.cdll,
                'GL', 
                mode=ctypes.RTLD_GLOBAL 
            ) 
        except OSError as err:
            raise ImportError("Unable to load OpenGL library", *err.args)
    @baseplatform.lazy_property
    def GLU(self):
        try:
            return ctypesloader.loadLibrary(
                ctypes.cdll,
                'GLU',
                mode=ctypes.RTLD_GLOBAL 
            )
        except OSError as err:
            return None
    @baseplatform.lazy_property
    def GLUT( self ):
        try:
            return ctypesloader.loadLibrary(
                ctypes.cdll,
                'glut', 
                mode=ctypes.RTLD_GLOBAL 
            )
        except OSError as err:
            return None
    # GLX doesn't seem to have its own loadable module?
    @baseplatform.lazy_property
    def GLX(self): return self.GL

    @baseplatform.lazy_property
    def GLES1(self):
        try:
            return ctypesloader.loadLibrary(
                ctypes.cdll,
                'GLESv1_CM', # ick
                mode=ctypes.RTLD_GLOBAL 
            )
        except OSError as err:
            return None
    @baseplatform.lazy_property
    def GLES2(self):
        try:
            return ctypesloader.loadLibrary(
                ctypes.cdll,
                'GLESv2', 
                mode=ctypes.RTLD_GLOBAL 
            )
        except OSError as err:
            return None
    @baseplatform.lazy_property
    def GLES3(self):
        # implementers guide says to use the same name for the DLL
        return self.GLES2
    
    @baseplatform.lazy_property
    def glXGetProcAddressARB(self):
        base = self.GLX.glXGetProcAddressARB
        base.restype = ctypes.c_void_p
        return base
    @baseplatform.lazy_property
    def getExtensionProcedure(self):
        return self.glXGetProcAddressARB
    
    @baseplatform.lazy_property
    def GLE( self ):
        try:
            return ctypesloader.loadLibrary(
                ctypes.cdll,
                'gle', 
                mode=ctypes.RTLD_GLOBAL 
            )
        except OSError as err:
            return None

    DEFAULT_FUNCTION_TYPE = staticmethod( ctypes.CFUNCTYPE )

    # This loads the GLX functions from the GL .so, not sure if that's
    # really kosher...
    @baseplatform.lazy_property
    def GetCurrentContext( self ):
        return self.GL.glXGetCurrentContext

    def getGLUTFontPointer( self, constant ):
        """Platform specific function to retrieve a GLUT font pointer
        
        GLUTAPI void *glutBitmap9By15;
        #define GLUT_BITMAP_9_BY_15		(&glutBitmap9By15)
        
        Key here is that we want the addressof the pointer in the DLL,
        not the pointer in the DLL.  That is, our pointer is to the 
        pointer defined in the DLL, we don't want the *value* stored in
        that pointer.
        """
        name = [ x.title() for x in constant.split( '_' )[1:] ]
        internal = 'glut' + "".join( [x.title() for x in name] )
        pointer = ctypes.c_void_p.in_dll( self.GLUT, internal )
        return ctypes.c_void_p(ctypes.addressof(pointer))
    
    @baseplatform.lazy_property
    def glGetError( self ):
        return self.GL.glGetError
    



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_vertex_program4'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_vertex_program4',error_checker=_errors._error_checker)
GL_VERTEX_ATTRIB_ARRAY_INTEGER_NV=_C('GL_VERTEX_ATTRIB_ARRAY_INTEGER_NV',0x88FD)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetVertexAttribIivEXT(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetVertexAttribIuivEXT(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint)
def glVertexAttribI1iEXT(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttribI1ivEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glVertexAttribI1uiEXT(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttribI1uivEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint)
def glVertexAttribI2iEXT(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttribI2ivEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glVertexAttribI2uiEXT(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttribI2uivEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint)
def glVertexAttribI3iEXT(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttribI3ivEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glVertexAttribI3uiEXT(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttribI3uivEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLbyteArray)
def glVertexAttribI4bvEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glVertexAttribI4iEXT(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttribI4ivEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttribI4svEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLubyteArray)
def glVertexAttribI4ubvEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glVertexAttribI4uiEXT(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttribI4uivEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVertexAttribI4usvEXT(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glVertexAttribIPointerEXT(index,size,type,stride,pointer):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ATI_element_array'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ATI_element_array',error_checker=_errors._error_checker)
GL_ELEMENT_ARRAY_ATI=_C('GL_ELEMENT_ARRAY_ATI',0x8768)
GL_ELEMENT_ARRAY_POINTER_ATI=_C('GL_ELEMENT_ARRAY_POINTER_ATI',0x876A)
GL_ELEMENT_ARRAY_TYPE_ATI=_C('GL_ELEMENT_ARRAY_TYPE_ATI',0x8769)
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei)
def glDrawElementArrayATI(mode,count):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLsizei)
def glDrawRangeElementArrayATI(mode,start,end,count):pass
@_f
@_p.types(None,_cs.GLenum,ctypes.c_void_p)
def glElementPointerATI(type,pointer):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_EXT_swap_control'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_EXT_swap_control',error_checker=_errors._error_checker)

@_f
@_p.types(_cs.c_int,)
def wglGetSwapIntervalEXT():pass
@_f
@_p.types(_cs.BOOL,_cs.c_int)
def wglSwapIntervalEXT(interval):pass



'''OpenGL extension NV.vertex_program4

This module customises the behaviour of the 
OpenGL.raw.GL.NV.vertex_program4 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension builds on the common assembly instruction set
	infrastructure provided by NV_gpu_program4, adding vertex program-specific
	features.
	
	This extension provides the ability to specify integer vertex attributes
	that are passed to vertex programs using integer data types, rather than
	being converted to floating-point values as in existing vertex attribute
	functions.  The set of input and output bindings provided includes all
	bindings supported by ARB_vertex_program.  This extension provides
	additional input bindings identifying the index of the vertex when vertex
	arrays are used ("vertex.id") and the instance number when instanced
	arrays are used ("vertex.instance", requires EXT_draw_instanced).  It
	also provides output bindings allowing vertex programs to directly specify
	clip distances (for user clipping) plus a set of generic attributes that
	allow programs to pass a greater number of attributes to subsequent
	pipeline stages than is possible using only the pre-defined fixed-function
	vertex outputs.
	
	By and large, programs written to ARB_vertex_program can be ported
	directly by simply changing the program header from "!!ARBvp1.0" to
	"!!NVvp4.0", and then modifying instructions to take advantage of the
	expanded feature set.  There are a small number of areas where this
	extension is not a functional superset of previous vertex program
	extensions, which are documented in the NV_gpu_program4 specification.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/vertex_program4.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.vertex_program4 import *
from OpenGL.raw.GL.NV.vertex_program4 import _EXTENSION_NAME

def glInitVertexProgram4NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glVertexAttribI1ivEXT=wrapper.wrapper(glVertexAttribI1ivEXT).setInputArraySize(
    'v', 1
)
glVertexAttribI2ivEXT=wrapper.wrapper(glVertexAttribI2ivEXT).setInputArraySize(
    'v', 2
)
glVertexAttribI3ivEXT=wrapper.wrapper(glVertexAttribI3ivEXT).setInputArraySize(
    'v', 3
)
glVertexAttribI4ivEXT=wrapper.wrapper(glVertexAttribI4ivEXT).setInputArraySize(
    'v', 4
)
glVertexAttribI1uivEXT=wrapper.wrapper(glVertexAttribI1uivEXT).setInputArraySize(
    'v', 1
)
glVertexAttribI2uivEXT=wrapper.wrapper(glVertexAttribI2uivEXT).setInputArraySize(
    'v', 2
)
glVertexAttribI3uivEXT=wrapper.wrapper(glVertexAttribI3uivEXT).setInputArraySize(
    'v', 3
)
glVertexAttribI4uivEXT=wrapper.wrapper(glVertexAttribI4uivEXT).setInputArraySize(
    'v', 4
)
glVertexAttribI4bvEXT=wrapper.wrapper(glVertexAttribI4bvEXT).setInputArraySize(
    'v', 4
)
glVertexAttribI4svEXT=wrapper.wrapper(glVertexAttribI4svEXT).setInputArraySize(
    'v', 4
)
glVertexAttribI4ubvEXT=wrapper.wrapper(glVertexAttribI4ubvEXT).setInputArraySize(
    'v', 4
)
glVertexAttribI4usvEXT=wrapper.wrapper(glVertexAttribI4usvEXT).setInputArraySize(
    'v', 4
)
# INPUT glVertexAttribIPointerEXT.pointer size not checked against 'size,type,stride'
glVertexAttribIPointerEXT=wrapper.wrapper(glVertexAttribIPointerEXT).setInputArraySize(
    'pointer', None
)
glGetVertexAttribIivEXT=wrapper.wrapper(glGetVertexAttribIivEXT).setOutput(
    'params',size=(1,),orPassIn=True
)
glGetVertexAttribIuivEXT=wrapper.wrapper(glGetVertexAttribIuivEXT).setOutput(
    'params',size=(1,),orPassIn=True
)
### END AUTOGENERATED SECTION


from OpenGL.arrays import vbo
from OpenGL.GLES2.VERSION import GLES2_2_0
from OpenGL.GLES2.OES import mapbuffer

class Implementation( vbo.Implementation ):
    """OpenGL-based implementation of VBO interfaces"""
    def __init__( self ):
        for name in self.EXPORTED_NAMES:
            for source in [ GLES2_2_0, mapbuffer ]:
                for possible in (name,name+'OES'):
                    try:
                        setattr( self, name, getattr( source, possible ))
                    except AttributeError as err:
                        pass 
                    else:
                        found = True
                assert found, name
        if GLES2_2_0.glBufferData:
            self.available = True
Implementation.register()



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_tessellation_program5'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_tessellation_program5',error_checker=_errors._error_checker)
GL_MAX_PROGRAM_PATCH_ATTRIBS_NV=_C('GL_MAX_PROGRAM_PATCH_ATTRIBS_NV',0x86D8)
GL_TESS_CONTROL_PROGRAM_NV=_C('GL_TESS_CONTROL_PROGRAM_NV',0x891E)
GL_TESS_CONTROL_PROGRAM_PARAMETER_BUFFER_NV=_C('GL_TESS_CONTROL_PROGRAM_PARAMETER_BUFFER_NV',0x8C74)
GL_TESS_EVALUATION_PROGRAM_NV=_C('GL_TESS_EVALUATION_PROGRAM_NV',0x891F)
GL_TESS_EVALUATION_PROGRAM_PARAMETER_BUFFER_NV=_C('GL_TESS_EVALUATION_PROGRAM_PARAMETER_BUFFER_NV',0x8C75)




'''OpenGL extension ARB.vertex_blend

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.vertex_blend to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides the ability to replace the single
	modelview transformation with a set of n vertex units. (Where
	n is constrained to an implementation defined maximum.) Each
	unit has its own modelview transform matrix. For each unit,
	there is a current weight associated with the vertex. When
	this extension is enabled the vertices are transformed by
	the modelview matrices of all of the enabled units. Afterward,
	these results are scaled by the weights for the respective
	units and then summed to create the eye-space vertex. A
	similar procedure is followed for the normals, except they
	are transformed by the inverse transpose of the modelview
	matrices.
	
	This extension is an orthoganalized version of functionality
	already provided by other 3D graphics API's.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/vertex_blend.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.vertex_blend import *
from OpenGL.raw.GL.ARB.vertex_blend import _EXTENSION_NAME

def glInitVertexBlendARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glWeightbvARB.weights size not checked against size
glWeightbvARB=wrapper.wrapper(glWeightbvARB).setInputArraySize(
    'weights', None
)
# INPUT glWeightsvARB.weights size not checked against size
glWeightsvARB=wrapper.wrapper(glWeightsvARB).setInputArraySize(
    'weights', None
)
# INPUT glWeightivARB.weights size not checked against size
glWeightivARB=wrapper.wrapper(glWeightivARB).setInputArraySize(
    'weights', None
)
# INPUT glWeightfvARB.weights size not checked against size
glWeightfvARB=wrapper.wrapper(glWeightfvARB).setInputArraySize(
    'weights', None
)
# INPUT glWeightdvARB.weights size not checked against size
glWeightdvARB=wrapper.wrapper(glWeightdvARB).setInputArraySize(
    'weights', None
)
# INPUT glWeightubvARB.weights size not checked against size
glWeightubvARB=wrapper.wrapper(glWeightubvARB).setInputArraySize(
    'weights', None
)
# INPUT glWeightusvARB.weights size not checked against size
glWeightusvARB=wrapper.wrapper(glWeightusvARB).setInputArraySize(
    'weights', None
)
# INPUT glWeightuivARB.weights size not checked against size
glWeightuivARB=wrapper.wrapper(glWeightuivARB).setInputArraySize(
    'weights', None
)
# INPUT glWeightPointerARB.pointer size not checked against 'type,stride'
glWeightPointerARB=wrapper.wrapper(glWeightPointerARB).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION